"""Script for running tsunami inundation scenario for Dampier, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project_urs.py
The output sww file is stored in project_urs.output_time_dir 

The scenario is defined by a triangular mesh created from project_urs.polygon,
the elevation data and a simulated submarine landslide.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
from os import sep
from os.path import dirname, basename
from os import mkdir, access, F_OK
from shutil import copy
import time
import sys

# Related major packages
from anuga.shallow_water import Domain
from anuga.shallow_water import Dirichlet_boundary
from anuga.shallow_water import File_boundary
from anuga.shallow_water import Reflective_boundary
from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts
from anuga.pmesh.mesh_interface import create_mesh_from_regions
from anuga.geospatial_data.geospatial_data import Geospatial_data
from anuga.abstract_2d_finite_volumes.util import start_screen_catcher, copy_code_files
from anuga_parallel.parallel_abstraction import get_processor_name

# Application specific imports
import project_urs   # Definition of file names and polygons

#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------

copy_code_files(project_urs.output_build_time_dir,__file__, 
               dirname(project_urs.__file__)+sep+ project_urs.__name__+'.py' )

start_screen_catcher(project_urs.output_build_time_dir)

print "Processor Name:",get_processor_name()
print 'USER: ', project_urs.user

#-------------------------------------------------------------------------------
# Preparation of topographic data
#
# Convert ASC 2 DEM 2 PTS using source data and store result in source data
# Do for coarse and fine data
# Fine pts file to be clipped to area of interest
#-------------------------------------------------------------------------------
print"project_urs.combined_dir_name",project_urs.combined_dir_name
'''
# topography directory filenames
onshore_in_dir_name = project_urs.onshore_in_dir_name
coast_in_dir_name = project_urs.coast_in_dir_name
offshore_in_dir_name = project_urs.offshore_in_dir_name
offshore1_in_dir_name = project_urs.offshore1_in_dir_name
offshore2_in_dir_name = project_urs.offshore2_in_dir_name

onshore_dir_name = project_urs.onshore_dir_name
coast_dir_name = project_urs.coast_dir_name
offshore_dir_name = project_urs.offshore_dir_name
offshore1_dir_name = project_urs.offshore1_dir_name
offshore2_dir_name = project_urs.offshore2_dir_name

# creates DEM from asc data
print "creates DEMs from asc data"
convert_dem_from_ascii2netcdf(onshore_in_dir_name,
                              basename_out=onshore_dir_name,
                              use_cache=True, verbose=True)
#creates pts file for onshore DEM
print "creates pts file for onshore DEM"
dem2pts(onshore_dir_name, use_cache=True, verbose=True)

print'create Geospatial onshore objects from topographies'
G = Geospatial_data(file_name = onshore_dir_name + '.pts') +\
    Geospatial_data(file_name = coast_in_dir_name + '.txt') +\
    Geospatial_data(file_name = offshore_in_dir_name + '.txt') 
#    +\
#    Geospatial_data(file_name = offshore1_dir_name + '.pts') +\
#    Geospatial_data(file_name = offshore2_dir_name + '.pts')
     

print'clip combined geospatial object by bounding polygon'
G_clipped = G.clip(project_urs.poly_all)

print'export combined DEM file'
if access(project_urs.topographies_dir,F_OK) == 0:
    mkdir (project_urs.topographies_dir)
G.export_points_file(project_urs.combined_dir_name + '.txt')

print'split combined data set'
G_small, G_other = G_clipped.split(0.1, True)

print'export split DEM file'
G_small.export_points_file(project_urs.combined_dir_name + '_small' + '.txt')
#G_other.export_points_file(project_urs.combined_dir_name + '_other' + '.pts')

'''
print 'start reading:',project_urs.combined_dir_name + '.txt'
G = Geospatial_data(file_name = (project_urs.combined_dir_name + '.txt'))
G_clipped = G.clip(project_urs.poly_topo_clip)

print 'start split'
#G_smallest, G_other = G.split(0.1,True)

print 'start export',project_urs.combined_smallest_dir_name + '.txt'
#G.export_points_file(project_urs.combined_smaller_dir_name + '.txt')
G_clipped.export_points_file(project_urs.combined_smallest_dir_name + '.txt')

#-------------------------------------------------------------------------
# Convert URS to SWW file for boundary conditions 
#-------------------------------------------------------------------------
print 'starting to create boundary conditions'
#boundaries_in_dir_name = project_urs.boundaries_in_dir_name

#print 'minlat=project_urs.north_boundary, maxlat=project_urs.south_boundary',project_urs.north_boundary, project_urs.south_boundary
#print 'minlon= project_urs.west_boundary, maxlon=project_urs.east_boundary',project_urs.west_boundary, project_urs.east_boundary
'''       
from anuga.shallow_water.data_manager import urs_ungridded2sww

print 'boundaries_in_dir_name',project_urs.boundaries_in_dir_name
print 'project.boundaries_dir_name',project_urs.boundaries_dir_name

urs_ungridded2sww(project_urs.boundaries_in_dir_name, project_urs.boundaries_dir_name,
                  verbose=True, mint=5000, maxt=35000, zscale=1)
'''




