"""Common filenames and locations for topographic data, meshes and outputs.
Also includes origin for slump scenario.
"""

from os import sep, environ, getenv, getcwd,umask
from os.path import expanduser, basename
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon, number_mesh_triangles
import sys
from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
from time import localtime, strftime, gmtime
from anuga.utilities.system_tools import get_user_name, get_host_name

codename = 'project.py'

home = getenv('INUNDATIONHOME') + sep +'data'+sep #Sandpit's parent dir   
user = get_user_name()
host = get_host_name()
#needed when running using mpirun, mpirun doesn't inherit umask from .bashrc
umask(002)

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_name = 'shark_bay'
scenario = 'shark_bay_tsunami_scenario_2006'

#time stuff
time = strftime('%Y%m%d_%H%M%S',gmtime()) #gets time for new dir
build_time = time+'_build'
run_time = time+'_run'

#tide = -3.9
#tide = 0.0
tide = 3.6

#Maybe will try to make project a class to allow these parameters to be passed in.
alpha = 0.1
friction=0.01
finaltime=25000
starttime=3600
setup='final'

#dir_comment='_trial_'+str(tide)+'_'+str(user)
#dir_comment='_final_'+str(tide)+'_'+str(user)
#time_thinning=4
#yieldstep=60
#res_factor = 1

if setup =='trial':
    print'trial'
    res_factor=10
    time_thinning=48
    yieldstep=240
if setup =='basic': 
    print'basic'
    res_factor=4
    time_thinning=12
    yieldstep=120
if setup =='final': 
    print'final'
    res_factor=1.1
    time_thinning=4
    yieldstep=60


dir_comment='_'+setup+'_'+str(tide)+'_'+str(user)

# onshore data from 30m DTED level 2
onshore_name = 'dli_dem' # get from Neil/Ingo (DEM or topo data)
offshore_name = 'pt_hedland_bathy_edit'
offshore1_name = '1'
offshore2_name = '2'
coast_name = 'Coastline'

#final topo name
combined_name ='pt_hedland_combined_elevation'
combined_small_name = 'pt_hedland_combined_elevation_small'
combined_smallest_name = 'pt_hedland_export'

anuga_dir = home+state+sep+scenario+sep+'anuga'+sep

topographies_in_dir = home+state+sep+scenario+sep+'elevation_final'+sep+'20070416'+sep+'points'+sep
topographies_dir = anuga_dir+'topographies'+sep

# input topo file location
onshore_in_dir_name = topographies_in_dir + onshore_name
coast_in_dir_name = topographies_in_dir + coast_name
offshore_in_dir_name = topographies_in_dir + offshore_name
offshore1_in_dir_name = topographies_in_dir + offshore1_name
offshore2_in_dir_name = topographies_in_dir + offshore2_name

onshore_dir_name = topographies_dir + onshore_name
coast_dir_name = topographies_dir + coast_name
offshore_dir_name = topographies_dir + offshore_name
offshore1_dir_name = topographies_dir + offshore1_name
offshore2_dir_name = topographies_dir + offshore2_name

#final topo files
combined_dir_name = topographies_dir + combined_name
#combined_time_dir_name = topographies_time_dir + combined_name
combined_small_dir_name = topographies_dir + combined_small_name
combined_smallest_dir_name = topographies_dir + combined_smallest_name

meshes_dir = anuga_dir+'meshes'+sep
meshes_dir_name = meshes_dir + scenario_name

polygons_dir = anuga_dir+'polygons'+sep
tide_dir = anuga_dir+'tide_data'+sep

#boundaries locations
boundaries_name = 'shark_bay'

boundaries_in_dir = anuga_dir+'boundaries'+sep+'urs'+sep+'1_10000'+sep
boundaries_in_dir_name = boundaries_in_dir + boundaries_name
boundaries_dir = anuga_dir+'boundaries'+sep
boundaries_dir_name = boundaries_dir + boundaries_name

#output locations
output_dir = anuga_dir+'outputs'+sep
output_build_time_dir = output_dir+build_time+sep
output_run_time_dir = output_dir +run_time+dir_comment+sep
output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing

#gauges
gauge_name = 'gauge_location_port_hedland.csv' 
gauge_name_test = 'gauge_checking_test.csv' 
gauges_dir = anuga_dir+'gauges'+sep
gauges_dir_name = gauges_dir + gauge_name
gauges_dir_name_test = gauges_dir + gauge_name_test

tide_dir = anuga_dir+'tide_data'+sep

buildings_filename = gauges_dir + 'pt_hedland_res.csv'
buildings_filename_out = 'pt_hedland_res_modified.csv'
buildings_filename_damage_out = 'pt_hedland_res_modified_damage.csv'
tidal_filename = tide_dir + 'pt_hedland_tide.txt'
community_filename = gauges_dir + 'CHINS_v2.csv'
community_scenario = gauges_dir + 'community_pt_hedland.csv'

# clipping region to make DEM (pts file) from onshore data
eastingmin = 594000
eastingmax = 715000
northingmin = 7720000
northingmax = 7880000

# for ferret2sww
south = degminsec2decimal_degrees(-20,30,0)
north = degminsec2decimal_degrees(-17,10,0)
west = degminsec2decimal_degrees(117,00,0)
east = degminsec2decimal_degrees(120,00,0)

# region to export (used from export_results.py)
e_min_area = 648000
e_max_area = 675000
n_min_area = 7745000
n_max_area = 7761000

export_region = [[e_min_area,n_min_area],[e_min_area,n_max_area],
                 [e_max_area,n_max_area],[e_max_area,n_min_area]]
                 
refzone = 50 

#from anuga.coordinate_transforms.redfearn import redfearn
poly_all = read_polygon(polygons_dir+'boundary_extent.csv')
res_poly_all = 250000*res_factor

#Interior region - Pt Hedland town
i0 = [668000, 7757000]
i1 = [659000, 7755000]
i2 = [660000, 7749000]
i3 = [667000, 7746000]
i4 = [678000, 7751000]

poly_pt_hedland = [i0, i1, i2, i3, i4]
res_pt_hedland=500*res_factor

#Are there other significant features?
j0 = [670000, 7760000]
j1 = [633000, 7745000]
j2 = [665000, 7743000]
j3 = [690000, 7755000]

poly_region = [j0, j1, j2, j3]
res_region = 50000*res_factor

#poly_mainland = read_polygon(polygons_dir+'Initial_Condition.csv')

poly_topo_clip = [[664000,7752000],[664000,7754000],
                  [666000,7754000],[666000,7752000]]

interior_regions = [[poly_pt_hedland,res_pt_hedland],[poly_region,res_region]
#                    ,[poly_region,res_region]
                    ]

trigs_min = number_mesh_triangles(interior_regions, poly_all, res_poly_all)

print 'min number triangles', trigs_min


